---
title: 文章标题
keywords: 关键词1, 关键词2
desc: 这里写文章简介
---

## 添加文章

* 在本文件所在目录创建 markdown 以  `.md` 结尾的文件，比如 `first.md`
* 在 `sidebar.yaml` 中添加侧边栏链接

```markdown
items:
-   label: Brief
    file: README.md
-   label: First
    file: first.md
```

## 更多例子

更多请访问: [teedoc.neucrack.com](https://teedoc.neucrack.com/) 或者 [teedoc.github.io](https://teedoc.github.io/)

更多例子访问: [github.com/teedoc/teedoc.github.io](https://github.com/teedoc/teedoc.github.io) 或者 [https://github.com/teedoc/template](https://github.com/teedoc/template) , 或 [sipeed wiki](https://github.com/sipeed/sipeed_wiki)


